@@ -282,7 +282,9 @@ ClientApp::scheduleClientRestart(double retryTime)
 void
 ClientApp::handleClientConnected(const Event&, void*)
 {
-    LOG((CLOG_NOTE "connected to server"));
+    // using CLOG_PRINT here allows the GUI to see that the client is connected
+    // regardless of which log level is set
+    LOG((CLOG_PRINT "connected to server"));
     resetRestartTimeout();
     updateStatus();
 }
