@@ -22,8 +22,7 @@
 // XMTThreadUnavailable
 //
 
-String
-XMTThreadUnavailable::getWhat() const throw()
+std::string XMTThreadUnavailable::getWhat() const noexcept
 {
     return format("XMTThreadUnavailable", "cannot create thread");
 }
