@@ -746,8 +746,7 @@ MSWindowsDesks::deskThread(void* vdesk)
     }
 }
 
-MSWindowsDesks::Desk*
-MSWindowsDesks::addDesk(const String& name, HDESK hdesk)
+MSWindowsDesks::Desk* MSWindowsDesks::addDesk(const std::string& name, HDESK hdesk)
 {
     Desk* desk      = new Desk;
     desk->m_name     = name;
@@ -782,7 +781,7 @@ MSWindowsDesks::checkDesk()
     // get current desktop.  if we already know about it then return.
     Desk* desk;
     HDESK hdesk  = openInputDesktop();
-    String name = getDesktopName(hdesk);
+    std::string name = getDesktopName(hdesk);
     Desks::const_iterator index = m_desks.find(name);
     if (index == m_desks.end()) {
         desk = addDesk(name, hdesk);
@@ -900,18 +899,17 @@ MSWindowsDesks::closeDesktop(HDESK desk)
     }
 }
 
-String
-MSWindowsDesks::getDesktopName(HDESK desk)
+std::string MSWindowsDesks::getDesktopName(HDESK desk)
 {
     if (desk == NULL) {
-        return String();
+        return {};
     }
     else {
         DWORD size;
         GetUserObjectInformation(desk, UOI_NAME, NULL, 0, &size);
         TCHAR* name = (TCHAR*)alloca(size + sizeof(TCHAR));
         GetUserObjectInformation(desk, UOI_NAME, name, size, &size);
-        String result(name);
+        std::string result(name);
         return result;
     }
 }
