@@ -22,7 +22,7 @@
 // BaseClientProxy
 //
 
-BaseClientProxy::BaseClientProxy(const String& name) :
+BaseClientProxy::BaseClientProxy(const std::string& name) :
     m_name(name),
     m_x(0),
     m_y(0)
@@ -49,8 +49,7 @@ BaseClientProxy::getJumpCursorPos(SInt32& x, SInt32& y) const
     y = m_y;
 }
 
-String
-BaseClientProxy::getName() const
+std::string BaseClientProxy::getName() const
 {
     return m_name;
 }
