@@ -1,7 +1,7 @@
 /*
  * barrier -- mouse and keyboard sharing utility
  * Copyright (C) 2012-2016 Symless Ltd.
- * Copyright (C) 2002 Chris Schoeneman
+ * Copyright (C) 2004 Chris Schoeneman
  * 
  * This package is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,17 +18,16 @@
 
 #pragma once
 
-#include "server/ClientProxy1_0.h"
+#include "server/ClientProxy1_1.h"
 
-//! Proxy for client implementing protocol version 1.1
-class ClientProxy1_1 : public ClientProxy1_0 {
+class IEventQueue;
+
+//! Proxy for client implementing protocol version 1.2
+class ClientProxy1_2 : public ClientProxy1_1 {
 public:
-    ClientProxy1_1(const String& name, barrier::IStream* adoptedStream, IEventQueue* events);
-    ~ClientProxy1_1();
+    ClientProxy1_2(const std::string& name, barrier::IStream* adoptedStream, IEventQueue* events);
+    ~ClientProxy1_2();
 
     // IClient overrides
-    virtual void        keyDown(KeyID, KeyModifierMask, KeyButton);
-    virtual void        keyRepeat(KeyID, KeyModifierMask,
-                            SInt32 count, KeyButton);
-    virtual void        keyUp(KeyID, KeyModifierMask, KeyButton);
+    virtual void        mouseRelativeMove(SInt32 xRel, SInt32 yRel);
 };
